@@ -1,5 +1,5 @@
 """
-    Homonim: Radiometric homogenisation of aerial and satellite imagery
+    Homonim: Correction of aerial and satellite imagery to surface reflectance
     Copyright (C) 2021 Dugal Harris
     Email: dugalh@gmail.com
 
@@ -19,6 +19,12 @@
 import os
 import pathlib
 
+from homonim.compare import RasterCompare
+from homonim.enums import Model, ProcCrs
+from homonim.fuse import RasterFuse
+from homonim.kernel_model import KernelModel
+from homonim.stats import ParamStats
+
 if '__file__' in globals():
     root_path = pathlib.Path(__file__).absolute().parents[1]
 else:
