@@ -34,7 +34,15 @@ OShape = Optional[Tuple[int, int]]
 
 class KernelModel:
 
-    def __init__(self, model: Model, kernel_shape: Tuple[int, int], find_r2: bool = False, **kwargs):
+    default_kernel_shape = (5, 5)           # default kernel shape
+    default_model = Model.gain_blk_offset   # default model
+
+    def __init__(self,
+        model: Model = default_model,
+        kernel_shape: Tuple[int, int] = default_kernel_shape,
+        find_r2: bool = False,
+        **kwargs
+    ):
         """
         A base class for surface reflectance modelling and correction of blocks of image data.
 
@@ -51,9 +59,9 @@ class KernelModel:
 
         Parameters
         ----------
-        model: homonim.enums.Model
+        model: homonim.enums.Model, optional
             Surface reflectance correction model.
-        kernel_shape: tuple
+        kernel_shape: tuple, optional
             (height, width) of the kernel in pixels.
         find_r2: bool, optional
             Whether to calculate *R*\\ :sup:`2` (coefficient of determination) for each kernel model, and include in
@@ -95,16 +103,16 @@ class KernelModel:
         """
         Utility method to create a KernelModel configuration dictionary that can be passed to
         :meth:`KernelModel.__init__` and :meth:`homonim.RasterFuse.process`.  Without arguments, the default
-        configuration values are returned.
+        configuration is returned.
 
         Parameters
         ----------
         r2_inpaint_thresh: float, optional
             *R*\\ :sup:`2` (coefficient of determination) threshold below which to `in-paint` kernel model parameters
-            from surrounding areas (applies to the :attr:`~homonim.enums.Model.gain_offset` model only).  For
+            from surrounding areas.  Applies to the :attr:`~homonim.enums.Model.gain_offset` model only.  For
             pixels where the model gives a poor approximation to the data (this can occur in areas where source and
             reference differ due to e.g. shadowing, land cover changes etc.), model offsets are interpolated from
-            surrounding areas, and gains re-estimated.  Set ``r2_inpaint_thresh`` to `None` to turn off in-painting.
+            surrounding areas, and gains re-estimated.  `None` turns off in-painting.
         mask_partial: bool, optional
             Mask output pixels not produced by full kernel or source/reference image coverage.  Useful for ensuring
             strict model validity, and reducing seam-lines between overlapping images.
@@ -353,6 +361,8 @@ class KernelModel:
         if self._r2_inpaint_thresh is not None:
             # fill/inpaint low R2 and negative gain areas in the offset parameter
             r2_mask = (param_ra.array[2] > self._r2_inpaint_thresh) & (param_ra.array[0] > 0) & mask
+            # NOTE: fillnodata does not release the GIL, so this can slow down processing, especially for proc-crs=src
+            # TODO: raise an issue with rasterio to release the GIL on fillnodata
             param_ra.array[1] = fillnodata(param_ra.array[1], r2_mask)
             param_ra.mask = mask  # re-mask as nodata areas will have been filled above
 
@@ -415,7 +425,8 @@ class KernelModel:
             RasterArray of sliding kernel model parameters. Gains in first band, offsets in the second, and optionally
             *R*\\ :sup:`2` for each kernel model in the third band when :attr:`find_r2` is True.
         """
-        # TODO : include a CRS comparison below i.e. one that is faster that rasterio's current implementation
+        # TODO : include a CRS comparison below i.e. one that is faster that rasterio's current implementation, and or
+        #  raise an issue with rasterio about the speed of crs comparison
         if (ref_ra.transform != src_ra.transform) or (ref_ra.shape != src_ra.shape):
             raise ValueError("'ref_ra' and 'src_ra' must have the same CRS, transform and shape")
 
